package com.ynet.life.sujrb.base;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.sujrb.vipclient.PBTaskInfo;
import java.io.File;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;
import java.util.Vector;

/* loaded from: com_ynet_life_sujrb_base.jar:com/ynet/life/sujrb/base/PBStandard.class */
public class PBStandard extends LifeStandard {
    protected static Map BUSINESS_TABLE;
    protected static Map PRIVATE_QUESTION_TABLE;
    protected static final String SQL_SELECT_PB_FLOW_TRACE = "SELECT PFT_ID,PFT_LASTID,PFT_ISFIRST,PFT_ISSINGLE FROM PB_FLOW_TRACE";
    protected static Map MVC_MAP = new HashMap();
    protected static Map MENU_TABLE = new HashMap();
    protected static List BLOCK_ACCOUNT_LIST = new Vector();
    protected static Map MVC_CONFIG = new HashMap();
    protected static Map<String, PBFlow> PBFLOW = null;
    protected static List CACHE_CONTENT_LIST = new ArrayList();
    protected static List WHITE_LIST = new ArrayList();
    protected static List<String> WEEKDAYISHOLIDAY_LIST = new ArrayList();
    protected static List<String> WEEKENDISWORKDAY_LIST = new ArrayList();
    protected static String APPR_SQL = "SELECT APR_CODE, APR_VALUE, APR_SHOWMSG FROM PUB_APPPAR where ";
    protected static String QUERY_SERVICE_TIME_OPEN_SQL = "SELECT SPR_VALUE\tFROM PUB_SYSPAR\tWHERE SPR_CODE = ?";
    protected static String QUERY_WORK_DAY_FLAG_SQL = "SELECT DAY_FLAG\tFROM PUB_WORKDAY WHERE DAY_DATE = ?";
    protected static String SEVICE_CODE = "PB_SERVICE_TIME_SWITCH";
    protected static String QUERY_WORK_DAY_SERVICE_TIME_SQL = "SELECT PST_WORKINGDAY_BEGIN,PST_WORKINGDAY_END,PST_PARENTNO,PST_STATE FROM PB_SERVICE_TIME WHERE PST_MENUCODE = ?";
    protected static String QUERY_HOLIDAY_SERVICE_TIME_SQL = "SELECT PST_HOLIDAY_BEGIN,PST_HOLIDAY_END,PST_PARENTNO,PST_STATE FROM PB_SERVICE_TIME WHERE PST_MENUCODE = ?";

    private PBStandard() {
    }

    public static void initialize(Map businessInfoTable) {
        BUSINESS_TABLE = businessInfoTable;
    }

    public static void initPrivateQuestion(Map privateQuestionTable) {
        PRIVATE_QUESTION_TABLE = privateQuestionTable;
    }

    public static void initializeMenuTable(Map menuTable, Map menuRef) {
        MENU_TABLE.putAll(menuTable);
        MVC_MAP.putAll(menuRef);
    }

    public static void initializeCacheContent(List cacheContentList) {
        CACHE_CONTENT_LIST = cacheContentList;
    }

    public static String getActionBusinessCode(String action) {
        return (String) MVC_MAP.get(action);
    }

    public static PBBusinessInfo getBusinessInfo(String businessCode) {
        if (BUSINESS_TABLE.containsKey(businessCode)) {
            return (PBBusinessInfo) BUSINESS_TABLE.get(businessCode);
        }
        return null;
    }

    public static PBTaskInfo getTaskInfo(String businessCode) {
        return (PBTaskInfo) MENU_TABLE.get(businessCode);
    }

    public static Map getPrivateQuestion() {
        new Hashtable();
        return PRIVATE_QUESTION_TABLE;
    }

    public static List getCacheConList() {
        new ArrayList();
        return CACHE_CONTENT_LIST;
    }

    public static void initWhiteList(List whiteList) {
        WHITE_LIST = whiteList;
    }

    public static List getWhiteList() {
        new ArrayList();
        return WHITE_LIST;
    }

    public static void initWeekendIsWorkdayList(List<String> weekendIsWorkdayList) {
        WEEKENDISWORKDAY_LIST = weekendIsWorkdayList;
    }

    public static List<String> getWeekendIsWorkdayList() {
        new ArrayList();
        return WEEKENDISWORKDAY_LIST;
    }

    public static void initWorkdayIsHolidayList(List<String> workdayIsHoliday) {
        WEEKDAYISHOLIDAY_LIST = workdayIsHoliday;
    }

    public static List<String> getWorkdayIsHolidayList() {
        new ArrayList();
        return WEEKDAYISHOLIDAY_LIST;
    }

    public static void syncParams(Context context) throws TranFailException {
        String language;
        try {
            language = (String) context.getDataValue("session_language");
        } catch (GENEException unused) {
            language = "ZH_CN";
        }
        Connection connection = null;
        try {
            try {
                Connection connection2 = LifeDBAccess.getConnection();
                connection = connection2;
                List resultList = LifeDBAccess.queryMultipleResult(connection2, String.valueOf(APPR_SQL) + "  APR_LANGUAGE = '" + language + "' ORDER BY APR_CODE", (List) null, 3);
                int resultSize = resultList.size();
                String appCode = "";
                DataElement dataElement = null;
                for (int i = 0; i < resultSize; i++) {
                    List innerList = (List) resultList.get(i);
                    String code = (String) innerList.get(0);
                    String value = (String) innerList.get(1);
                    String message = (String) innerList.get(2);
                    if (appCode != null && !appCode.equals(code)) {
                        appCode = code;
                        if (dataElement != null) {
                            context.addDataElement(dataElement);
                        }
                        dataElement = new IndexedCollection(appCode);
                    }
                    KeyedCollection kcoll = new KeyedCollection();
                    kcoll.put("key", value);
                    kcoll.put("value", message);
                    dataElement.addDataElement(kcoll);
                }
                if (dataElement != null) {
                    context.addDataElement(dataElement);
                }
                LifeDBAccess.releaseConnection(connection);
            } catch (Throwable th) {
                LifeDBAccess.releaseConnection(connection);
                throw th;
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "前端同步参数syncParams处理失败", e);
            LifeDBAccess.releaseConnection(connection);
        }
    }

    public static void syncSystemParams(Context context) throws TranFailException {
        Map paramMap = LifeStandard.getSystemParams();
        try {
            IndexedCollection icoll = new IndexedCollection("iSystemParams");
            for (String key : paramMap.keySet()) {
                String value = (String) paramMap.get(key);
                KeyedCollection kcoll = new KeyedCollection();
                kcoll.put("key", key);
                kcoll.put("value", value);
                icoll.addDataElement(kcoll);
            }
            context.addDataElement(icoll);
        } catch (Exception e) {
            Trace.logError("LifeAction", "同步系统参数syncSystemParams处理失败", e);
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v4 */
    /* JADX WARN: Type inference failed for: r0v5, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v9, types: [boolean] */
    public static void initMvcConfig(String filePath) throws TranFailException {
        File[] files = new File(filePath).listFiles();
        int length = files.length;
        int i = 0;
        while (true) {
            ?? r0 = i;
            if (r0 >= length) {
                return;
            }
            try {
                File file = files[i];
                String fileName = file.getName();
                r0 = fileName.endsWith(PBConstants.MVC_CONFIG_FIEL_PST_FIX);
                if (r0 != 0) {
                    String mvcConfigTxt = LifeFile.readTextFileToString(file.getPath(), "UTF-8");
                    MVC_CONFIG.put(fileName.subSequence(0, fileName.lastIndexOf(PBConstants.MVC_CONFIG_FIEL_PST_FIX)), mvcConfigTxt);
                }
                i++;
            } catch (TranFailException e) {
                throw r0;
            }
        }
    }

    public static void initFlowTrace(Connection connection) throws TranFailException {
        Map<String, PBFlow> result = new HashMap<>();
        PreparedStatement statement = null;
        ResultSet resultSet = null;
        try {
            try {
                PreparedStatement prepareStatement = connection.prepareStatement(SQL_SELECT_PB_FLOW_TRACE);
                statement = prepareStatement;
                resultSet = prepareStatement.executeQuery();
                while (resultSet.next()) {
                    String id = resultSet.getString(1);
                    String lastId = resultSet.getString(2);
                    String isFirst = resultSet.getString(3);
                    String isSingle = resultSet.getString(4);
                    result.put(id, new PBFlow(id, lastId, isFirst, isSingle));
                }
                if (resultSet != null) {
                    try {
                        resultSet.close();
                    } catch (SQLException ex) {
                        Trace.logError("LifeJDBC", "JDBC关闭异常", ex);
                        throw new TranFailException(ex);
                    }
                }
                if (statement != null) {
                    statement.close();
                }
                PBFLOW = result;
            } catch (SQLException ex2) {
                Trace.logError("LifeJDBC", "EBLN0000:::流程链表初始化异常", ex2);
                throw new TranFailException("EBLN0000", "流程链表初始化异常", ex2);
            }
        } catch (Throwable th) {
            if (resultSet != null) {
                try {
                    resultSet.close();
                } catch (SQLException ex3) {
                    Trace.logError("LifeJDBC", "JDBC关闭异常", ex3);
                    throw new TranFailException(ex3);
                }
            }
            if (statement != null) {
                statement.close();
            }
            throw th;
        }
    }

    public static PBFlow getFlowTrace(String id) {
        if (PBFLOW == null) {
            return null;
        }
        return PBFLOW.get(id);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v0 */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v15 */
    /* JADX WARN: Type inference failed for: r0v17, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v19, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v4, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v5, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v55 */
    /* JADX WARN: Type inference failed for: r0v57, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v59, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v65 */
    /* JADX WARN: Type inference failed for: r0v67, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v69, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v75, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v76 */
    /* JADX WARN: Type inference failed for: r0v78, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v80, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v86 */
    /* JADX WARN: Type inference failed for: r0v88, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v90, types: [java.sql.Connection] */
    public static boolean checkServiceTime(String businessCode) throws GENEException {
        ?? r0 = 0;
        Connection connection = null;
        try {
            try {
                connection = LifeDBAccess.getConnection();
                int openFlag = 0;
                List inputList = new ArrayList();
                inputList.add(SEVICE_CODE);
                List resultList = LifeDBAccess.querySingleResult(connection, QUERY_SERVICE_TIME_OPEN_SQL, inputList, 1);
                if (resultList.size() > 0) {
                    openFlag = Integer.parseInt((String) resultList.get(0));
                }
                if (openFlag != 1) {
                    ?? r02 = connection;
                    if (r02 == 0) {
                        return true;
                    }
                    try {
                        r02 = connection;
                        LifeDBAccess.releaseConnection((Connection) r02);
                        return true;
                    } catch (Exception e) {
                        LifeDBAccess.log((Exception) r02);
                        return true;
                    }
                }
                String sysDate = LifeStandard.getServerTime("yyyyMMdd");
                inputList.clear();
                inputList.add(sysDate);
                List resultList2 = LifeDBAccess.querySingleResult(connection, QUERY_WORK_DAY_FLAG_SQL, inputList, 1);
                int workDayFlag = 0;
                if (resultList2.size() > 0) {
                    workDayFlag = Integer.parseInt((String) resultList2.get(0));
                }
                inputList.clear();
                inputList.add(businessCode);
                List resultList3 = workDayFlag == 1 ? LifeDBAccess.querySingleResult(connection, QUERY_WORK_DAY_SERVICE_TIME_SQL, inputList, 4) : LifeDBAccess.querySingleResult(connection, QUERY_HOLIDAY_SERVICE_TIME_SQL, inputList, 4);
                if (resultList3.size() == 0) {
                    ?? r03 = connection;
                    if (r03 == 0) {
                        return true;
                    }
                    try {
                        r03 = connection;
                        LifeDBAccess.releaseConnection((Connection) r03);
                        return true;
                    } catch (Exception e2) {
                        LifeDBAccess.log((Exception) r03);
                        return true;
                    }
                }
                String serviceBeginTime = (String) resultList3.get(0);
                String serviceEndTime = (String) resultList3.get(1);
                String parentId = (String) resultList3.get(2);
                String state = (String) resultList3.get(3);
                String sysTime = LifeStandard.getServerTime("yyyyMMddHHmmss").substring(8, 12);
                if (sysTime.compareTo(serviceBeginTime) >= 0 && sysTime.compareTo(serviceEndTime) <= 0 && (state == null || "".equals(state) || "0".equals(state))) {
                    if (parentId == null || "".equals(parentId)) {
                        ?? r04 = connection;
                        if (r04 == 0) {
                            return true;
                        }
                        try {
                            r04 = connection;
                            LifeDBAccess.releaseConnection((Connection) r04);
                            return true;
                        } catch (Exception e3) {
                            LifeDBAccess.log((Exception) r04);
                            return true;
                        }
                    }
                    r0 = checkServiceTime(parentId.trim());
                    if (r0 != 0) {
                        ?? r05 = connection;
                        if (r05 == 0) {
                            return true;
                        }
                        try {
                            r05 = connection;
                            LifeDBAccess.releaseConnection((Connection) r05);
                            return true;
                        } catch (Exception e4) {
                            LifeDBAccess.log((Exception) r05);
                            return true;
                        }
                    }
                }
                ?? r06 = connection;
                if (r06 == 0) {
                    return false;
                }
                try {
                    r06 = connection;
                    LifeDBAccess.releaseConnection((Connection) r06);
                    return false;
                } catch (Exception e5) {
                    LifeDBAccess.log((Exception) r06);
                    return false;
                }
            } catch (Exception ex) {
                throw new TranFailException("EBLN0000", "检查交易服务时间时发生异常", ex);
            } catch (TranFailException e6) {
                throw r0;
            }
        } catch (Throwable th) {
            ?? r07 = connection;
            if (r07 != 0) {
                try {
                    r07 = connection;
                    LifeDBAccess.releaseConnection((Connection) r07);
                } catch (Exception e7) {
                    LifeDBAccess.log((Exception) r07);
                }
            }
            throw th;
        }
    }
}
